summaryrefslogtreecommitdiffstats
path: root/pytquic3/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'pytquic3/form.cpp')
-rw-r--r--pytquic3/form.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/pytquic3/form.cpp b/pytquic3/form.cpp
index 0d1255a..b0de614 100644
--- a/pytquic3/form.cpp
+++ b/pytquic3/form.cpp
@@ -598,14 +598,14 @@ void Uic::createFormImpl( const TQDomElement &e )
receiver = "self." + receiver;
out << indent << "self.connect(" << sender
- << ",SIGNAL(\"" << signal << "\")," << receiver;
+ << ",TQ_SIGNAL(\"" << signal << "\")," << receiver;
- // Normally we never use the SLOT() macro in case the
+ // Normally we never use the TQ_SLOT() macro in case the
// connection is to a method of a Python custom widget. The
// exception is if the receiver is a TQAxWidget where it must be
// used because the slots are dynamic.
if (isaxwidget)
- out << ",SLOT(\"" << slot << "\")";
+ out << ",TQ_SLOT(\"" << slot << "\")";
else
{
TQString mname = slot.left(slot.find('('));